OC.L10N.register(
    "nextcloud_announcements",
    {
    "Nextcloud announcements" : "Annunci di Nextcloud",
    "Nextcloud announcement" : "Annuncio di Nextcloud",
    "Read more" : "Leggi altro",
    "Disable announcements" : "Disabilita annunci",
    "(These announcements are only shown to administrators)" : "(Questi annunci sono mostrati solo agli amministratori)",
    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Gli annunci di Nextcloud portano le ultime notizie di Nextcloud nelle tue notifiche"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
